ENV_RX - Initiate a host command environment


void env_rx(name, fns, lg_def)
  char *name;
  int (*fns)();
  int lg_def;

The function fns will be called every time the S/REXX program will issue a
command to the name environment. name is a NULL terminated string which
will be translated into upper case by env_rx before use.

If the name environment already exists, it will be updated.

If fns is a NULL pointer, a previous name environment will be destroyed.

If lg_def is set to 1, name will become the default environment.

fns will receive a NULL terminated string containing the command and its
length:


int fns(string, l_string)
  char *string;
  int l_string;


Note that at first call, env_rx will also create the standard S/REXX UNIX
or WINDOWS environment.


Example:  A C demo1.c program:

-----------------------------------------------------------------------
int call_back(string, len)
  char *string;
{
    printf ("call_back: received \"%s\"\n", string);
    return(0);
}

main()
{
 env_rx("MyEnv", call_back, 0); /* MyEnv tranlated */
                                /* to MYENV        */
 run_rx("r_demo1", "/home/xed", NULL, NULL, NULL);
}
-----------------------------------------------------------------------


A r_demo1 S/REXX program called by the demo1 program:


-----------------------------------------------------------------------
address myenv 12**5.56
-----------------------------------------------------------------------



To compile and execute this program, issue the following commands:

    C{foo}% cd {install-dir}/demo/demo_sr
    C{demo_sr}% make demo1
    cc -O -o demo1 demo1.c ../../lib/sun4/libsr.o -I../../include  -lc -lm
    9.1u 1.4s 0:10 96% 0+900k 3+63io 0pf+0w
    C{demo_sr}% demo1
    call_back: received "1000570.58"
    C{demo_sr}%
