EXECIO - Input/Output Operations


EXECIO is not part of the S/REXX language, but for VM/CMS compatibility it
is implemented as an extension of the UNIX or WINDOWS environment.
Therefore, it is recommended to enclose it in quotes in order to prevent
the normal S/REXX variable substitution.

EXECIO format is:

EXECIO  |lines  |DISKR  fn ft {fd {linenum}}    {({FINIs} A B}
        |*      |DISKW  fn ft fd {linenum
        |               {recfm {lrecl}}}        {({FINIs} B C D}
        |       |DISKI  fn ft fd {linenum
        |               {recfm {lrecl}}}        {({FINIs} B C D}
        |       |DISKD  fn ft fd {linenum}      {(FINIs}

                |PRINT  printer {({FINIs} B C D E}


Options formats:

(A)     {Find /string/} {Zone n1 n2}    {FIFO|LIFO}     {SKip}
        {LOcate /string/}
        {Avoid /string/}

(B)     {Margins n1 n2} {STRIP} {NOTYPE {STEm xxx}
                                {VAR vvv}

(C)     {CAse U|M}

(D)     {STring xxx}

(E)     {Columns n}

where:

lines   is the number of processed lines. lines must be any non-negative
        integer.
        With the VAR option, lines must be 1.
        An asterisk * indicates that the operation is to terminate when a
        0-length line is read during an output operation, or when an
        end-of-file condition is detected during an input operation.
        When lines is specified as zero (0), no I/O operation takes place
        other than closing the file or printer when the FINIS option is
        specified.
        For a DISKW or PRINT operation, if the STEM operand has not been
        specified and the lines operand exceeds the number of lines
        available on the program stack, S/REXX waits for user input at the
        terminal the S/REXX program was started from. If lines has been
        specified as a *, reading an empty line terminates the operation.

DISKR   reads lines from a disk file to the stack or S/REXX variables.

DISKW   writes lines from the stack, S/REXX variables or command line to a
        disk file.
        When using the DISKW function to write in the middle of a file,
        for example to write a string at line 10 of a 2000 line file,
        S/REXX does not truncate the file at line 10. Instead, it checks
        the string length, compares it to the original line 10 length, and
        moves the remainder of the file either to the left (shortening the
        file) or to the right, depending on whether the new line is
        shorter (left) or longer (right) than the original line.
        With large files, this process may take a while.

DISKI   inserts lines from the stack, S/REXX variables or command line to
        a disk file **before** the specified line. The remainder of the
        file is moved to the right. With large files, this process may
        take a while.

DISKD   removes the specified lines. The line pointer remains unchanged.

PRINT (UNIX)

        writes lines from the stack, S/REXX variables or command line to
        the printer defined by the printer operand. S/REXX keeps these
        lines in memory until the FINIS operand is used to close the
        printer. Several printers may be opened simultaneously.

PRINT (WINDOWS)

        writes lines from the stack, S/REXX variables or command line to
        the printer named "printer". When printer is specified as an *,
        the default printer is used. printer can be specified within
        quotes.
        S/REXX keeps these lines in memory until the FINIS operand is used
        to close the printer. Only one printer may be opened at a time.
        The default printer can be changed with the dy_printer built-in
        function.

        PRINT is only supported by wsrexx.exe. srexx.exe will return an
        error code when PRINT is used.

recfm   is implemented for VM/CMS compatibility. It must be V or F. When F
        is specified, the default lrecl is 80.

lrecl   specifies the length of each updated line of the file. When the
        data is larger than this length, it is truncated. When the data is
        shorter, it is padded with blanks.

fn      is the filename part of the file. A period (.) may be used if no
        filename is required.

        When fd is specified as a period (.), fn may be the full UNIX or
        WINDOWS pathname, including the file-directory and filetype parts.
        This allows the user to use a UNIX or WINDOWS like way to describe
        a file,

        such as:

                execio 1 diskw ~/foo.c . .(

        instead of the VM/CMS way, such as:

                execio 1 diskw foo c ~(

ft      is the filetype part of the file. A period (.) may be used if no
        filetype is required.

fd      is the directory part of the file. When fd is not specified or
        specified as an asterisk (*) during an input operation, all the
        directories described in the PATH environment variable are
        searched.

linenum is the absolute line number where a file operation is to begin.
        When not specified, or specified as 0, reading begins at the first
        line, and writing at the last line for the first operation.
        Subsequent operations will resume at the line where the previous
        operation ended.

FINIs   causes the specified file or printer to be closed.
        A subsequent DISKR operation will return the first line in the
        file.
        A subsequent DISKW operation will append data at the end of the
        file.
        A subsequent PRINT operation will start a new print job.


Option A
--------

FInd    writes 2 strings to the stack LIFO (last-in first-out) by default,
        or FIFO (first-in first-out) when the FIFO option is specified:

           1) the content of the first matched line.

           2) the relative and absolute line numbers of the first line
              that begins with the string specified between delimiters.
              The delimiter is the first non-blank character found after
              the FIND keyword. It does not need to be a /.

              The ZONE option allows the user to search for a string
              starting at the specified n1 column. n2-n1 must be greater
              than the length of string.

          When used with the STEM xxx option, FIND will update the xxxn
          variables in the following way:

            1) xxx0 is set to 2.

            2) xxx1 is filled with the first line that matches the
               condition.

            3) xxx2 is filled with the relative and absolute line numbers.
               The relative line number is the number of lines scanned
               before the match occurs.


LOcate  is like the FIND option, except the string may occur any place
        within a line (or zone portion of that line).

Avoid   is like the LOCATE option, except the search is for a line (or
        zone portion of that line) that does not contain the specified
        characters.

Zone    restricts the portion of the lines searched during a FIND, LOCATE
        or AVOID operation.
        The search is performed between columns n1 and n2 (inclusive). If
        n2 is specified as *, the search is performed through the end of
        the line.

FIFO    the lines are written to the stack in first-in first-out order.
        This is the default, except for the FIND, LOCATE or AVOID
        operations.

LIFO    the lines are written to the stack in last-in first-out order.
        This is the default for the FIND, LOCATE or AVOID operations.

SKIP    prevents a read operation from writing to the stack.


Option B
--------

Margins specifies that only columns n1 through n2 (inclusive) are to be
        processed. If n2 is specified as *, the process is performed
        through the end of the line.

STRIP   removes the trailing blanks from any output lines or lines
        returned.

NOTYPE  suppresses the display of any S/REXX messages when an I/O error
        occurs.

STEm xxx   the variables xxxn will be used to supply input data for
           output-type operations. They will be the destination for output
           for the input-type operations.

           xxx1 is the first used or created variable, xxx2 the second,
           and so on. xxx0 will be set to the number of lines returned
           for the input-type operations.

VAR     vvv the variable vvv will be used to supply input data for
        output-type operations. It will be the destination for output for
        the input-type operations.
        When VAR is specified, lines must be specified as 1.


Option C
--------

Case U  the data read is translated to uppercase.
Case M  the data read is not translated. This is the default.


Option D
--------

STRING  supplies output data explicitly. Any characters following the
        STRING keyword are treated as string data. Therefore, STRING must
        be the final option on the command line.

The EXECIO return codes have the following meanings:

    0       Success.
    2       End of file condition on DISKR operation.
    3       No match when using a FIND/LOCATE/AVOID option.
    24      Bad parameter list.
    28      File not found.
    29      Invalid printer (WINDOWS only)
    101     I/O error.
    2008    Invalid STEM or VAR operand.


Option E
--------


Columns N   On WINDOWS systems, EXECIO uses the WINDOWS printer API to
            determine the number of available columns for printing, and
            wraps larger lines.
            When specified, N overrides this computed width.


Notes:  On WINDOWS systems, the HOME environment variable is usually not
        defined. In this case, the "~/" or "~\" directory shortcut is
        translated into "C:\".

        If fn, ft or fd contains blanks, they must be surrounded with
        quotes or double quotes.

Examples:

--------------------------------------------------------------------------
'execio 2 diskr foo c ../usr/john 5(stem ff.'
--------------------------------------------------------------------------

places the lines 5 and 6 of the ../usr/john/foo.c file into the ff.1 and
ff.2 variables. ff.0 is set to 2.

--------------------------------------------------------------------------
'execio 1 diskr foo c ../usr/john'
--------------------------------------------------------------------------

since the ../usr/john/foo.c file was not closed by the previous EXECIO
call, the next line (line 7) is placed into the stack.

--------------------------------------------------------------------------
'execio 2 diskw foo . ~ 7 f 90(finis stem ff.'
--------------------------------------------------------------------------

writes the content of ff.1 and ff.2 into the ~/foo file, starting at line
7, and padding those lines with blanks up to 90 columns. The ~/foo file is
closed at EXECIO termination. Note the use of the period (.) placeholder
to specify that the file does not have any filetype.

--------------------------------------------------------------------------
'execio * diskr . cshrc ~(find $setenv$ stem ff.'
--------------------------------------------------------------------------

scans the ~/.cshrc file, looking for the setenv string. Note the use of
the period (.) placeholder to specify that the file does not have any
filename.

--------------------------------------------------------------------------
'execio 1 diskw foo c ~(string /* NOTREACHED */'
--------------------------------------------------------------------------

adds the string /* NOTREACHED */ at the end of the file ~/foo.c.

--------------------------------------------------------------------------
'execio * diskr profile sedit "c:\Program Files\SEDIT"(stem ff.'
--------------------------------------------------------------------------

or

--------------------------------------------------------------------------
'execio * diskr "c:\Program Files\SEDIT\profile.sedit" . .(stem ff.'
--------------------------------------------------------------------------

reads the "c:\Program Files\SEDIT\profile.sedit" file.


--------------------------------------------------------------------------
'execio * PRINT "LASERJET IIISI" (stem ff.'
--------------------------------------------------------------------------

on WINDOWS, prints on the "LASERJET IIISI" printer. Quotes are mandatory
when the name of the printer contains blanks.


--------------------------------------------------------------------------
'execio * PRINT * (stem ff.'
--------------------------------------------------------------------------

on WINDOWS, prints on the default printer.
