/*
 *  send_sedit: Sends the command "com" to SEDIT using the port
 *              described by SEDIT_INPORT, or to port 1999 when
 *              SEDIT_INPORT is missing.
 *
 *   "com" is a null terminated string. Every command is delimited
 *   with a \n.
 *
 *   Example:  to tell SEDIT to edit file "foo.c" at line 5, use
 *
 *             send_sedit("xed foo.c\n5");
 */

#include <stdio.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <errno.h>
#include <fcntl.h>


void send_sedit(com)
  char *com;
{
  int sock;
  struct sockaddr_in server;
  struct hostent *hp, *gethostbyname();

  char *getenv(), *s_inport;
  int port, len;


  if ( NULL == (s_inport = getenv("SEDIT_INPORT")) ) port = 1999;
  else
     if ( 1 != sscanf(s_inport, "%d", &port) )
      { printf ("send_sedit: invalid SEDIT_INPORT\n");
        return;
      }

 /*
  * Make a socket
  */
  if ( 0 > (sock = socket(AF_INET, SOCK_STREAM, 0)) )
    { printf ("send_sedit: unable to create a socket\n");
      perror("send_sedit");
      return;
    }                /* eject */

 /*
  * Connect socket
  */
  server.sin_family = AF_INET;
  if ( 0 == (hp = gethostbyname("localhost")) )
   { printf ("send_sedit: unable to gethostbyname()\n");
     perror("send_sedit");
     return;
   }

  bcopy((char *)hp->h_addr, (char *)&server.sin_addr, hp->h_length);
  server.sin_port = htons(port);

  if ( 0 > connect(sock, (struct sockaddr *)&server, sizeof(server)) )
   { printf ("send_sedit: unable to connect socket\n");
     perror("send_sedit");
     close(sock);
     return;
   }


  len = 1+strlen(com);                  /* With the trailing NULL */
  if ( write(sock, com, len) != len )
   { printf ("send_sedit: unable to write\n");
     perror("send_sedit");
   }

  close(sock);
  return;
}
